"""Specific views for events

:organization: Logilab
:copyright: 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
"""
__docformat__ = "restructuredtext en"

from logilab.common.date import date_range

from cubicweb.predicates import is_instance
from cubicweb_web.view import EntityAdapter
from cubicweb_web.views.baseviews import TextView


class EventTextView(TextView):
    __select__ = is_instance('Event')

    def cell_call(self, row, col):
        entity = self.cw_rset.get_entity(row, col)
        self.w(u'%s: %s' % (entity.printable_value('diem'), entity.title))


class EventICalendarableAdapter(EntityAdapter):
    __regid__ = 'ICalendarable'
    __select__ = is_instance('Event')

    component = "event"

    @property
    def start(self):
        return self.entity.diem

    @property
    def stop(self):
        return self.entity.end_date


class EventICalendarViewsAdapter(EntityAdapter):
    """calendar views interface"""
    __regid__ = 'ICalendarViews'
    __select__ = is_instance('Event')

    def matching_dates(self, begin, end):
        """calendar views interface"""
        start = self.entity.diem
        stop = self.entity.end_date
        if not start and not stop:
            return []
        elif start and not stop:
            stop = start+1
        elif stop and not start:
            start = stop-1
        return list(date_range(start, stop))



from logilab.common.testlib import unittest_main
from cubicweb_web.devtools.testlib import AutomaticWebTest


class AutomaticWebTest(AutomaticWebTest):

    def to_test_etypes(self):
        return set(('Event',))

    def list_startup_views(self):
        return ()


if __name__ == '__main__':
    unittest_main()



"""entity classes for task entities

:organization: Logilab
:copyright: 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
"""
__docformat__ = "restructuredtext en"

from cubicweb.entities import AnyEntity, fetch_config


class Event(AnyEntity):
    __regid__ = 'Event'

    fetch_attrs, cw_fetch_order = fetch_config(['title'])

    def dc_title(self):
        return self.title



from cubicweb.predicates import is_instance
from cubicweb.sobjects.notification import ContentAddedView


class EventAddedView(ContentAddedView):
    """get notified from new events"""
    __select__ = is_instance('Event')
    content_attr = 'description'



# pylint: disable-msg=W0622
"""cubicweb-event packaging information"""

modname = 'event'
distname = "cubicweb-event"

numversion = (2, 1, 0)
version = '.'.join(str(num) for num in numversion)

license = 'LGPL'
author = "Logilab"
author_email = "contact@logilab.fr"
web = 'http://www.cubicweb.org/project/%s' % distname
description = "event component for the CubicWeb framework"
classifiers = [
    'Environment :: Web Environment',
    'Framework :: CubicWeb',
    'Programming Language :: Python',
    'Programming Language :: JavaScript',
    ]

__depends__ = {
    "cubicweb": ">=4.5.2,<6.0.0",
    "cubicweb_web": ">=1.0.0,<2.0.0",
}



from yams.buildobjs import EntityType, String, Datetime
from cubicweb import _

try:
    from yams.buildobjs import RichString
except ImportError:
    from cubicweb.schema import RichString


class Event(EntityType):
    """a calendar event"""
    title = String(required=True, fulltextindexed=True, maxsize=128)
    diem = Datetime(required=True)
    end_date = Datetime(required=False)
    type = String(internationalizable=True,
                  vocabulary=(_('appointment'), _('convention'), _('meeting'),
                              _('social event'), _('work'), _('training')),
                  default='appointment')
    location = String(fulltextindexed=True, maxsize=256)
    description = RichString(fulltextindexed=True)
